LocalSink class abstract

Implementers

Constructors

LocalSink()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read({DateTime? from, DateTime? to, int? limit}) Future<List<AuditEntry>>
toString() String
A string representation of this object.
inherited
write(AuditEntry entry) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited