Certificate class
X.509 certificate wrapper (library-internal representation).
Constructors
-
Certificate({required Bytes derBytes, required String serial, required KeyMaterial publicKey, required DateTime notBefore, required DateTime notAfter, required String signatureAlgorithm, List<
Uri> crlDistributionPoints = const [], required String fingerprint}) -
const
Properties
-
crlDistributionPoints
→ List<
Uri> -
final
- derBytes → Bytes
-
final
- fingerprint → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExpired → bool
-
no setter
- notAfter → DateTime
-
final
- notBefore → DateTime
-
final
- publicKey → KeyMaterial
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serial → String
-
final
- signature → Bytes
-
This cert's signature (issued by the parent).
no setter
- signatureAlgorithm → String
-
final
- tbsBytes → Bytes
-
To-Be-Signed bytes — verified against the parent cert's publicKey during
chain validation.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromPem(
String pem) → Certificate - Parses from a PEM (-----BEGIN CERTIFICATE-----) string.